# Aplicaciones

Lista de proyectos y aplicaciones que utilizan, extienden o documentan la API de Series de Tiempo.

## Propias

* [datosgobar/series-tiempo-ar-landing](https://github.com/datosgobar/series-tiempo-ar-landing): Tablero web modular y parametrizado para armar un [dashboard de indicadores](https://datosgobar.github.io/series-tiempo-ar-landing/) con datos y gráficos, basado en la API de Series de Tiempo.
* [datosgobar/series-tiempo-ar-call-generator](https://github.com/datosgobar/series-tiempo-ar-call-generator): [Form](https://datosgobar.github.io/series-tiempo-ar-call-generator/) liviano y sencillo para generar llamadas a la API de Series de Tiempo.

## De terceros

* [fmgarciadiaz/PortalHacienda](https://github.com/fmgarciadiaz/PortalHacienda): Interface en R para usar la API por [@fergd1978](https://twitter.com/fergd1978).
* [http://series-de-tiempo-ar-graficos.netlify.com/](http://series-de-tiempo-ar-graficos.netlify.com/): Navegador y visualizador web de series por [@SoyYoConBonete_](https://twitter.com/SoyYoConBonete_).

## Contacto

¿Desarrollaste una librería o tenés un proyecto que usa la API? Te [invitamos a contarnos](https://twitter.com/datosgobar) así la agregamos a esta lista.

Para todo lo demás, podés mandarnos tu comentario o consulta a [datos@modernizacion.gob.ar](mailto:datos@modernizacion.gob.ar).
